pub fn evaluate(constraint: &OdrlConstraint, ctx: &ConstraintContext) -> boolExpand description
Evaluate a single ODRL constraint against a context.
Returns true if the constraint is satisfied, false otherwise.
pub fn evaluate(constraint: &OdrlConstraint, ctx: &ConstraintContext) -> boolEvaluate a single ODRL constraint against a context.
Returns true if the constraint is satisfied, false otherwise.