pub enum OdrlRuleType {
Permission,
Prohibition,
Duty,
}Expand description
The type of an ODRL rule.
Variants
Permission
Grants the assignee the action on the target (if constraints hold).
Prohibition
Denies the assignee the action on the target (if constraints hold).
Duty
Obligates the assignee to perform the action.